const state = {
    currencies: [],
    currency: null, 
    loadingCurrencies: false,
}

const getters = {
    currencies(state) {
        return state.currencies
    },
    currencySymbols(state) {
        return state.currencies && state.currencies.filter(c => state.currency.id !== c.id).map(c => c.symbol)
    },
    currency(state) {
        return state.currency
    },
    currencySymbol(state) {
        return state.currency && state.currency.symbol
    },
    loadingCurrencies(state) {
        return state.loadingCurrencies
    }
}

const mutations = {
    setCurrency(state, currencySymbol) {
        if (currencySymbol) {
            state.currency = state.currencies.find(c => (c.symbol === currencySymbol))
            return
        }
        
        state.currency = state.currencies.find(c => (c.base === true))
    },
    /**
     * 
     * @param {*} state 
     * @param {*} payload 
     */
    setCurrencies(state, payload) {
        state.currencies = payload
    },
    /**
     * 
     * @param {*} state 
     * @param {*} payload 
     */
    setLoadingCurrencies(state, payload) {
        state.loadingCurrencies = !!payload
    }
}

const actions = {
    /**
     * 
     * @param {*} param0 
     * @param {*} payload 
     */
    initCurrencies({ commit }, payload) {
        commit('setCurrencies', payload)
        commit('setCurrency')
        commit('setLoadingCurrencies')
    },
    /**
     * 
     * @param {*} param0 
     * @param {*} payload 
     */
    resetCurrency({ commit }) {
        commit('setLoadingCurrencies', true)
        commit('setCurrencies', [])
    },
    /**
     * 
     * @param {*} param0 
     * @param {*} payload 
     */
    changeCurrency({ commit }, currencySymbol) {
        commit('setCurrency', currencySymbol)
    }
}

export default {
    state,
    getters,
    mutations,
    actions
}